==> linuxconf-tools-1.1.src.tar.gz: linuxconf-tools-1.1/nadoc/nadoc.pm <==
/* _dict.cc 12/09/98 16.33.42 */
/* clsflat.cc 15/09/98 22.51.36 */
PRIVATE int CLSFORM::flatfunc (const char *clsname,
	 NAP_LIST&lst,
	 bool vue_interne,
	 NAP_FCT **tbfct,
	 int nbfct);
PUBLIC void CLSFORM::flatfunc (const char *clsname,
	 NAP_LIST&lst,
	 bool vue_interne,
	 bool sgml,
	 FILE *fout);
PUBLIC void CLSFORM::flatfunc (NAP_LIST&lst,
	 bool vue_interne,
	 bool sgml,
	 FILE *fout);
/* clsform.cc 16/09/98 01.33.20 */
PUBLIC void CLSFORM::gentest0 (CLS_INFO *info, FILE *fout);
PUBLIC int CLSFORM::gentest (FILE *fout);
/* clsinfo.cc 16/09/98 01.31.12 */
PUBLIC CLS_INFO::CLS_INFO (const char *_nom);
PUBLIC CLS_INFO::~CLS_INFO (void);
PUBLIC CLS_DERIVE::CLS_DERIVE (CLS_INFO *_info,
	 CLS_INFO *_base,
	 const char *_opt);
PUBLIC CLS_DERIVE::~CLS_DERIVE (void);
PUBLIC CLS_INFO *CLS_INFOS::getitem (int no)const;
PUBLIC CLS_DERIVE *CLS_DERIVES::getitem (int no)const;
PUBLIC CLS_INHER *CLS_INHERS::getitem (int no)const;
PUBLIC CLSFORM::CLSFORM (void);
PUBLIC CLSFORM::~CLSFORM (void);
PUBLIC CLS_INFO *CLSFORM::addclass (const char *nom);
PUBLIC void CLSFORM::addder (CLS_INFO *info,
	 CLS_INFO *base,
	 const char *opt);
PUBLIC int CLSFORM::read (const char *fname);
PUBLIC void CLSFORM::unknown (void);
/* clsprint.cc 15/09/98 21.20.32 */
PRIVATE int CLSFORM::printr (const char *base,
	 FILE *fout,
	 int indent,
	 bool sgml);
PUBLIC int CLSFORM::print (FILE *fout, bool sgml);
/* crossfix.cc 29/11/98 13.00.08 */
/* crossref.cc 15/09/98 22.40.36 */
/* crosstbl.cc 29/11/98 13.00.26 */
/* histo.cc 12/09/98 16.33.42 */
/* nacom.cc 12/09/98 16.33.42 */
PUBLIC void COM_INDEX::dump (PAGIN *pout);
/* nacom1.cc 12/09/98 16.33.42 */
PUBLIC COM_INDEX::COM_INDEX (void);
PUBLIC int COM_INDEX::ok (void);
PUBLIC COM_INDEX::~COM_INDEX (void);
PUBLIC void COM_INDEX::addspec (const char *ident,
	 const char *fname,
	 long offset,
	 int noline,
	 char *tbcle[],
	 int nbcle,
	 int specbeg);
PUBLIC int COM_INDEX::scansrc (const char *fname);
PUBLIC void COM_INDEX::sort (void);
/* nacom2.cc 12/09/98 16.34.30 */
PUBLIC int COM_INDEX::locate (int pos,
	 const char *ident,
	 char *tbcle[],
	 int nbcle,
	 COM_SPC **ptspc);
PUBLIC int COM_INDEX::scanargv (int argc,
	 char *argv[],
	 const char *path,
	 int recur);
PUBLIC int COM_INDEX::chknotusedp (PAGIN_V *pout, PAGIN_V *pmat);
PUBLIC int COM_INDEX::chknotused (FILE *fout);
/* nadoc.cc 29/11/98 12.54.04 */
/* nap.cc 16/09/98 01.11.48 */
PUBLIC NAP_LIST::~NAP_LIST (void);
PUBLIC int NAP_LIST::parse (const char *fname);
PRIVATE void NAP_LIST::init (void);
PUBLIC NAP_LIST::NAP_LIST (const char *fname);
PUBLIC NAP_LIST::NAP_LIST (void);
PUBLIC int NAP_LIST::getnb (void);
PUBLIC NAP_FCT *NAP_LIST::getitem (int no);
PRIVATE NAP_FCT *NAP_LIST::locate0 (const char *fctname, int pos);
PUBLIC NAP_FCT *NAP_LIST::locate (const char *fctname);
PUBLIC NAP_FCT *NAP_LIST::locatenext (NAP_FCT *info);
PUBLIC NAP_FCT *NAP_LIST::locatemember (const char *cls,
	 NAP_FCT *fct);
/* naperm.cc 12/09/98 16.33.44 */
/* pagin.cc 13/09/98 19.06.50 */
PUBLIC PAGIN_V::PAGIN_V (void);
PUBLIC VIRTUAL PAGIN_V::~PAGIN_V (void);
PUBLIC VIRTUAL int PAGIN_V::set_format (int _format);
PUBLIC int PAGIN_V::get_format (void);
PUBLIC VIRTUAL void PAGIN_V::soussection (void);
PUBLIC VIRTUAL void PAGIN_V::finsous (void);
PUBLIC PAGIN::PAGIN (void);
PUBLIC PAGIN::~PAGIN (void);
PUBLIC int PAGIN::openerr (const char *fname,
	 int quit,
	 int _gauche,
	 int _lenlin,
	 int _linpag);
PUBLIC int PAGIN::openfile (FILE *_fout,
	 int _gauche,
	 int _lenlin,
	 int _linpag);
PUBLIC void PAGIN::close (void);
PUBLIC void PAGIN::form (void);
PUBLIC void PAGIN::printf (const char *ctl, ...);
PUBLIC void PAGIN::nl (void);
PUBLIC void PAGIN::check (int nbline);
PUBLIC void PAGIN::format_paragraphe (char *buf);
PUBLIC void PAGIN::format_titre (int niveau,
	 const char *secnum,
	 char *buf);
PUBLIC void PAGIN::format_spec (const char *filespec, const char *buf);
PUBLIC void PAGIN::format_fct (const char *fct, int premiere);
PUBLIC void PAGIN::format_ref (const char *);
PUBLIC int PAGIN::getpage (void);
PUBLIC void PAGIN_IDX::format_titre (int niveau,
	 const char *secnum,
	 char *buf);
PUBLIC void PAGIN_IDX::format_spec (const char *, const char *);
PUBLIC void PAGIN_IDX::format_fct (const char *, int);
PUBLIC PAGIN_IDX::PAGIN_IDX (PAGIN *_pout);
/* paging.cc 29/11/98 12.58.52 */
PUBLIC PAGIN_SGML::PAGIN_SGML (void);
PUBLIC PAGIN_SGML::~PAGIN_SGML (void);
PUBLIC int PAGIN_SGML::openerr (const char *fname, int quit);
PUBLIC void PAGIN_SGML::close (void);
PUBLIC int PAGIN_SGML::set_format (int _format);
PUBLIC void PAGIN_SGML::form (void);
PUBLIC void PAGIN_SGML::fputs (const char *buf, FILE *fout);
PUBLIC void PAGIN_SGML::printf (const char *ctl, ...);
PUBLIC void PAGIN_SGML::fprintf (FILE *f, const char *ctl, ...);
PUBLIC void PAGIN_SGML::nl (void);
PUBLIC void PAGIN_SGML::check (int);
PUBLIC void PAGIN_SGML::format_paragraphe (char *buf);
PUBLIC void PAGIN_SGML::format_titre (int niveau,
	 const char *secnum,
	 char *buf);
PUBLIC void PAGIN_SGML::format_spec (const char *filespec,
	 const char *buf);
PUBLIC void PAGIN_SGML::format_fct (const char *fct, int premiere);
PUBLIC void PAGIN_SGML::format_ref (const char *ref);
PUBLIC void PAGIN_SGML::soussection (void);
PUBLIC void PAGIN_SGML::finsous (void);
PUBLIC PAGIN_SGML_IDX::PAGIN_SGML_IDX (void);
PUBLIC PAGIN_SGML_IDX::~PAGIN_SGML_IDX (void);
PUBLIC void PAGIN_SGML_IDX::soussection (void);
PUBLIC void PAGIN_SGML_IDX::finsous (void);
PUBLIC void PAGIN_SGML_IDX::format_titre (int , const char *, char *);
PUBLIC void PAGIN_SGML_IDX::format_spec (const char *, const char *);
PUBLIC void PAGIN_SGML_IDX::format_fct (const char *, int);
PUBLIC int PAGIN_SGML_IDX::openerr (const char *, int quit);
/* paginh.cc 13/09/98 19.06.32 */
PUBLIC PAGIN_HTML::PAGIN_HTML (void);
PUBLIC PAGIN_HTML::~PAGIN_HTML (void);
PUBLIC int PAGIN_HTML::openerr (const char *_basename, int quit);
PUBLIC void PAGIN_HTML::close (void);
PUBLIC int PAGIN_HTML::set_format (int _format);
PUBLIC void PAGIN_HTML::form (void);
PUBLIC void PAGIN_HTML::fputs (const char *buf, FILE *fout);
PUBLIC void PAGIN_HTML::printf (const char *ctl, ...);
PUBLIC void PAGIN_HTML::fprintf (FILE *f, const char *ctl, ...);
PUBLIC void PAGIN_HTML::nl (void);
PUBLIC void PAGIN_HTML::check (int);
PUBLIC void PAGIN_HTML::format_paragraphe (char *buf);
PUBLIC void PAGIN_HTML::format_titre (int niveau,
	 const char *secnum,
	 char *buf);
PUBLIC void PAGIN_HTML::format_spec (const char *filespec,
	 const char *buf);
PUBLIC void PAGIN_HTML::format_fct (const char *fct, int premiere);
PUBLIC void PAGIN_HTML::format_ref (const char *ref);
PUBLIC void PAGIN_HTML::soussection (void);
PUBLIC void PAGIN_HTML::finsous (void);
PUBLIC PAGIN_HTML_IDX::PAGIN_HTML_IDX (void);
PUBLIC PAGIN_HTML_IDX::~PAGIN_HTML_IDX (void);
PUBLIC void PAGIN_HTML_IDX::soussection (void);
PUBLIC void PAGIN_HTML_IDX::finsous (void);
PUBLIC void PAGIN_HTML_IDX::format_titre (int niveau,
	 const char *secnum,
	 char *buf);
PUBLIC void PAGIN_HTML_IDX::format_spec (const char *filespec,
	 const char *buf);
PUBLIC void PAGIN_HTML_IDX::format_fct (const char *fct, int premiere);
PUBLIC int PAGIN_HTML_IDX::openerr (const char *_basename,
	 const char *_rel_path,
	 int quit);

==> linuxconf-tools-1.6.src.tar.gz: linuxconf-tools-1.6/nadoc/nadoc.pm <==
/* _dict.cc 12/09/98 16.33.42 */
/* clsflat.cc 15/09/98 22.51.36 */
PRIVATE int CLSFORM::flatfunc (const char *clsname,
	 NAP_LIST&lst,
	 bool vue_interne,
	 NAP_FCT **tbfct,
	 int nbfct);
PUBLIC void CLSFORM::flatfunc (const char *clsname,
	 NAP_LIST&lst,
	 bool vue_interne,
	 bool sgml,
	 FILE *fout);
PUBLIC void CLSFORM::flatfunc (NAP_LIST&lst,
	 bool vue_interne,
	 bool sgml,
	 FILE *fout);
/* clsform.cc 29/11/98 22.25.00 */
PUBLIC void CLSFORM::gentest0 (CLS_INFO *info, FILE *fout);
PUBLIC int CLSFORM::gentest (FILE *fout);
/* clsinfo.cc 16/09/98 01.31.12 */
PUBLIC CLS_INFO::CLS_INFO (const char *_nom);
PUBLIC CLS_INFO::~CLS_INFO (void);
PUBLIC CLS_DERIVE::CLS_DERIVE (CLS_INFO *_info,
	 CLS_INFO *_base,
	 const char *_opt);
PUBLIC CLS_DERIVE::~CLS_DERIVE (void);
PUBLIC CLS_INFO *CLS_INFOS::getitem (int no)const;
PUBLIC CLS_DERIVE *CLS_DERIVES::getitem (int no)const;
PUBLIC CLS_INHER *CLS_INHERS::getitem (int no)const;
PUBLIC CLSFORM::CLSFORM (void);
PUBLIC CLSFORM::~CLSFORM (void);
PUBLIC CLS_INFO *CLSFORM::addclass (const char *nom);
PUBLIC void CLSFORM::addder (CLS_INFO *info,
	 CLS_INFO *base,
	 const char *opt);
PUBLIC int CLSFORM::read (const char *fname);
PUBLIC void CLSFORM::unknown (void);
/* clsprint.cc 15/09/98 21.20.32 */
PRIVATE int CLSFORM::printr (const char *base,
	 FILE *fout,
	 int indent,
	 bool sgml);
PUBLIC int CLSFORM::print (FILE *fout, bool sgml);
/* crossfix.cc 29/11/98 22.25.18 */
/* crossref.cc 29/11/98 22.25.44 */
/* crosstbl.cc 29/11/98 13.00.26 */
/* histo.cc 12/09/98 16.33.42 */
/* nacom.cc 12/09/98 16.33.42 */
PUBLIC void COM_INDEX::dump (PAGIN *pout);
/* nacom1.cc 12/09/98 16.33.42 */
PUBLIC COM_INDEX::COM_INDEX (void);
PUBLIC int COM_INDEX::ok (void);
PUBLIC COM_INDEX::~COM_INDEX (void);
PUBLIC void COM_INDEX::addspec (const char *ident,
	 const char *fname,
	 long offset,
	 int noline,
	 char *tbcle[],
	 int nbcle,
	 int specbeg);
PUBLIC int COM_INDEX::scansrc (const char *fname);
PUBLIC void COM_INDEX::sort (void);
/* nacom2.cc 12/09/98 16.34.30 */
PUBLIC int COM_INDEX::locate (int pos,
	 const char *ident,
	 char *tbcle[],
	 int nbcle,
	 COM_SPC **ptspc);
PUBLIC int COM_INDEX::scanargv (int argc,
	 char *argv[],
	 const char *path,
	 int recur);
PUBLIC int COM_INDEX::chknotusedp (PAGIN_V *pout, PAGIN_V *pmat);
PUBLIC int COM_INDEX::chknotused (FILE *fout);
/* nadoc.cc 07/12/98 21.53.06 */
/* nap.cc 16/09/98 01.11.48 */
PUBLIC NAP_LIST::~NAP_LIST (void);
PUBLIC int NAP_LIST::parse (const char *fname);
PRIVATE void NAP_LIST::init (void);
PUBLIC NAP_LIST::NAP_LIST (const char *fname);
PUBLIC NAP_LIST::NAP_LIST (void);
PUBLIC int NAP_LIST::getnb (void);
PUBLIC NAP_FCT *NAP_LIST::getitem (int no);
PRIVATE NAP_FCT *NAP_LIST::locate0 (const char *fctname, int pos);
PUBLIC NAP_FCT *NAP_LIST::locate (const char *fctname);
PUBLIC NAP_FCT *NAP_LIST::locatenext (NAP_FCT *info);
PUBLIC NAP_FCT *NAP_LIST::locatemember (const char *cls,
	 NAP_FCT *fct);
/* naperm.cc 12/09/98 16.33.44 */
/* pagin.cc 13/09/98 19.06.50 */
PUBLIC PAGIN_V::PAGIN_V (void);
PUBLIC VIRTUAL PAGIN_V::~PAGIN_V (void);
PUBLIC VIRTUAL int PAGIN_V::set_format (int _format);
PUBLIC int PAGIN_V::get_format (void);
PUBLIC VIRTUAL void PAGIN_V::soussection (void);
PUBLIC VIRTUAL void PAGIN_V::finsous (void);
PUBLIC PAGIN::PAGIN (void);
PUBLIC PAGIN::~PAGIN (void);
PUBLIC int PAGIN::openerr (const char *fname,
	 int quit,
	 int _gauche,
	 int _lenlin,
	 int _linpag);
PUBLIC int PAGIN::openfile (FILE *_fout,
	 int _gauche,
	 int _lenlin,
	 int _linpag);
PUBLIC void PAGIN::close (void);
PUBLIC void PAGIN::form (void);
PUBLIC void PAGIN::printf (const char *ctl, ...);
PUBLIC void PAGIN::nl (void);
PUBLIC void PAGIN::check (int nbline);
PUBLIC void PAGIN::format_paragraphe (char *buf);
PUBLIC void PAGIN::format_titre (int niveau,
	 const char *secnum,
	 char *buf);
PUBLIC void PAGIN::format_spec (const char *filespec, const char *buf);
PUBLIC void PAGIN::format_fct (const char *fct, int premiere);
PUBLIC void PAGIN::format_ref (const char *);
PUBLIC int PAGIN::getpage (void);
PUBLIC void PAGIN_IDX::format_titre (int niveau,
	 const char *secnum,
	 char *buf);
PUBLIC void PAGIN_IDX::format_spec (const char *, const char *);
PUBLIC void PAGIN_IDX::format_fct (const char *, int);
PUBLIC PAGIN_IDX::PAGIN_IDX (PAGIN *_pout);
/* paging.cc 07/12/98 21.55.00 */
PUBLIC PAGIN_SGML::PAGIN_SGML (void);
PUBLIC PAGIN_SGML::~PAGIN_SGML (void);
PUBLIC int PAGIN_SGML::openerr (const char *fname,
	 const char *title,
	 const char *author,
	 int quit);
PUBLIC void PAGIN_SGML::close (void);
PUBLIC int PAGIN_SGML::set_format (int _format);
PUBLIC void PAGIN_SGML::form (void);
PUBLIC void PAGIN_SGML::fputs (const char *buf, FILE *fout);
PUBLIC void PAGIN_SGML::printf (const char *ctl, ...);
PUBLIC void PAGIN_SGML::fprintf (FILE *f, const char *ctl, ...);
PUBLIC void PAGIN_SGML::nl (void);
PUBLIC void PAGIN_SGML::check (int);
PUBLIC void PAGIN_SGML::format_paragraphe (char *buf);
PUBLIC void PAGIN_SGML::format_titre (int niveau,
	 const char *secnum,
	 char *buf);
PUBLIC void PAGIN_SGML::format_spec (const char *filespec,
	 const char *buf);
PUBLIC void PAGIN_SGML::format_fct (const char *fct, int premiere);
PUBLIC void PAGIN_SGML::format_ref (const char *ref);
PUBLIC void PAGIN_SGML::soussection (void);
PUBLIC void PAGIN_SGML::finsous (void);
PUBLIC PAGIN_SGML_IDX::PAGIN_SGML_IDX (void);
PUBLIC PAGIN_SGML_IDX::~PAGIN_SGML_IDX (void);
PUBLIC void PAGIN_SGML_IDX::soussection (void);
PUBLIC void PAGIN_SGML_IDX::finsous (void);
PUBLIC void PAGIN_SGML_IDX::format_titre (int , const char *, char *);
PUBLIC void PAGIN_SGML_IDX::format_spec (const char *, const char *);
PUBLIC void PAGIN_SGML_IDX::format_fct (const char *, int);
PUBLIC int PAGIN_SGML_IDX::openerr (const char *, int quit);
/* paginh.cc 13/09/98 19.06.32 */
PUBLIC PAGIN_HTML::PAGIN_HTML (void);
PUBLIC PAGIN_HTML::~PAGIN_HTML (void);
PUBLIC int PAGIN_HTML::openerr (const char *_basename, int quit);
PUBLIC void PAGIN_HTML::close (void);
PUBLIC int PAGIN_HTML::set_format (int _format);
PUBLIC void PAGIN_HTML::form (void);
PUBLIC void PAGIN_HTML::fputs (const char *buf, FILE *fout);
PUBLIC void PAGIN_HTML::printf (const char *ctl, ...);
PUBLIC void PAGIN_HTML::fprintf (FILE *f, const char *ctl, ...);
PUBLIC void PAGIN_HTML::nl (void);
PUBLIC void PAGIN_HTML::check (int);
PUBLIC void PAGIN_HTML::format_paragraphe (char *buf);
PUBLIC void PAGIN_HTML::format_titre (int niveau,
	 const char *secnum,
	 char *buf);
PUBLIC void PAGIN_HTML::format_spec (const char *filespec,
	 const char *buf);
PUBLIC void PAGIN_HTML::format_fct (const char *fct, int premiere);
PUBLIC void PAGIN_HTML::format_ref (const char *ref);
PUBLIC void PAGIN_HTML::soussection (void);
PUBLIC void PAGIN_HTML::finsous (void);
PUBLIC PAGIN_HTML_IDX::PAGIN_HTML_IDX (void);
PUBLIC PAGIN_HTML_IDX::~PAGIN_HTML_IDX (void);
PUBLIC void PAGIN_HTML_IDX::soussection (void);
PUBLIC void PAGIN_HTML_IDX::finsous (void);
PUBLIC void PAGIN_HTML_IDX::format_titre (int niveau,
	 const char *secnum,
	 char *buf);
PUBLIC void PAGIN_HTML_IDX::format_spec (const char *filespec,
	 const char *buf);
PUBLIC void PAGIN_HTML_IDX::format_fct (const char *fct, int premiere);
PUBLIC int PAGIN_HTML_IDX::openerr (const char *_basename,
	 const char *_rel_path,
	 int quit);
